menu
kaalka package
documentation
kaalka.dart
Kaalka class
Kaalka class
dark_mode
light_mode
Kaalka
class
Implementers
KaalkaNTP
Constructors
Kaalka
({
DateTime
?
time
})
Properties
h
↔
int
getter/setter pair
hashCode
→
int
The hash code for this object.
no setter
inherited
m
↔
int
getter/setter pair
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
s
↔
int
getter/setter pair
Methods
decrypt
(
dynamic
data
, {
String
?
timeKey
})
→
Future
encrypt
(
dynamic
data
, {
String
?
timeKey
})
→
Future
<
String
>
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
kaalka package
documentation
kaalka
Kaalka class
kaalka library