KaalkaFile class

File chunking and encryption (Kaalka-style)

Constructors

KaalkaFile()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decryptFileChunks(List<Map<String, dynamic>> encryptedChunks, String receiverId, {String? timestamp}) Uint8List
Decrypt file chunks
encryptFileChunks(Uint8List fileBytes, String senderId, String receiverId, {String? timestamp}) List<Map<String, dynamic>>
Encrypt file as chunks

Constants

chunkSize → const int