KaalkaNTP class

KaalkaNTP: Kaalka encryption using NTP or user-provided timestamp. Compatible with Python/JS implementations.

Inheritance

Constructors

KaalkaNTP([dynamic timeKey])

Properties

h int
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
m int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s int
getter/setter pairinherited

Methods

decrypt(dynamic data, {String? timeKey}) Future
inherited
encrypt(dynamic data, {String? timeKey}) Future<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decryptWithNtp(String data, {dynamic timeKey}) Future<String>
Decrypt data using NTP time or provided timeKey.
encryptWithNtp(String data, {dynamic timeKey}) Future<String>
Encrypt data using NTP time or provided timeKey.
getNtpTime() Future<List<int>>
Get current time from NTP server (returns h, m, s). This is a stub; for real NTP, use a Dart NTP package or implement UDP query.