Packet class

Packet: Example wrapper for encrypting/decrypting packets with Kaalka.

Constructors

Packet(String data, {dynamic timeKey})

Properties

data String
getter/setter pair
encrypted String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeKey ↔ dynamic
getter/setter pair

Methods

decrypt() Future<String>
Decrypt the packet data.
encrypt() Future<void>
Encrypt the packet data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

receive_data_over_network() Future<String>
receiver() → void
send_data_over_network(String data) → void
sender() → void